@@ -402,19 +402,13 @@ class Wizard(BaseFrontend):
             self.live_installer.connect(
                 'key-press-event', self.a11y_profile_keys)
 
-        # Wait for sound.target to become ready
-        self.soundWatcher = misc.SystemdUnitWatcher('sound.target',
-                                                    self.play_system_ready)
-
-        self.save_oem_metapackages_list()
-
-    def play_system_ready(self):
-        # play the system ready sound
         if osextras.find_on_path('canberra-gtk-play'):
             subprocess.Popen(
                 ['canberra-gtk-play', '--id=system-ready'],
                 preexec_fn=misc.drop_all_privileges)
 
+        self.save_oem_metapackages_list()
+
     def save_oem_metapackages_list(self, wait_finished=False):
         ''' If we can, update the apt indexes. Then run 'ubuntu-drivers
         list-oem' to find any OEM metapackages for this system. If we've
@@ -576,11 +570,6 @@ class Wizard(BaseFrontend):
             GLib.source_remove(self.timeout_id)
         self.timeout_id = GLib.timeout_add(300, self.check_returncode)
 
-    def set_connectivity_state(self, state):
-        for p in self.pages:
-            if hasattr(p.ui, 'plugin_set_connectivity_state'):
-                p.ui.plugin_set_connectivity_state(state)
-
     def set_online_state(self, state):
         for p in self.pages:
             if hasattr(p.ui, 'plugin_set_online_state'):
@@ -1128,7 +1117,6 @@ class Wizard(BaseFrontend):
         self.allow_go_backward(False)
 
         misc.add_connection_watch(self.network_change)
-        misc.add_connection_watch(self.set_connectivity_state, global_only=False)
 
     def set_window_hints(self, widget):
         if (self.oem_user_config or
@@ -1758,7 +1746,13 @@ class Wizard(BaseFrontend):
         # Setup zfs layout
         use_zfs = self.db.get('ubiquity/use_zfs')
         if use_zfs == 'true':
+            env = os.environ.copy()
+            zfs_keystore_key = self.db.get('ubiquity/zfs_keystore_key')
+            if zfs_keystore_key:
+                os.environ['ZFS_KS_KEY'] = zfs_keystore_key
             misc.execute_root('/usr/share/ubiquity/zsys-setup', 'init')
+            os.environ.clear()
+            os.environ.update(env)
 
         syslog.syslog('Starting the installation')
 
