@@ -84,6 +84,8 @@ class PageBase(plugin.PluginUI):
             else:
                 self.suffix = '-desktop'
         self.allow_password_empty = False
+        self.hostname_error_text = ""
+        self.domain_connection_error_text = ""
 
     def set_fullname(self, value):
         """Set the user's full name."""
@@ -411,14 +413,6 @@ class PageGtk(PageBase):
 
         self.controller.allow_go_forward(complete)
 
-    def on_password_toggle_visibility(self, widget, icon_pos, event):
-        from gi.repository import Gtk
-        visibility = self.password.get_visibility()
-        self.password.set_visibility(not visibility)
-        self.verified_password.set_visibility(not visibility)
-        self.password.set_icon_from_icon_name(
-            Gtk.EntryIconPosition.SECONDARY, ('view-conceal-symbolic', 'view-reveal-symbolic')[visibility])
-
     def on_username_changed(self, widget):
         self.username_edited = (widget.get_text() != '')
 
@@ -522,9 +516,7 @@ class PageGtk(PageBase):
 
         self.controller._wizard.set_page_title(self)
 
-    def plugin_set_connectivity_state(self, state):
-        # For AD we need network connectivity but it can be local and not
-        # necessarily internet connectivity
+    def plugin_set_online_state(self, state):
         if not state:
             self.login_directory.set_active(False)
         self.login_directory.set_sensitive(state)
@@ -562,7 +554,7 @@ class PageKde(PageBase):
         self.controller = controller
 
         from PyQt5 import uic
-        from PyQt5.QtGui import QPixmap, QIcon
+        from PyQt5.QtGui import QPixmap
 
         self.plugin_widgets = uic.loadUi(
             '/usr/share/ubiquity/qt/stepUserSetup.ui')
@@ -595,14 +587,11 @@ class PageKde(PageBase):
         self.page.password_error_image.setPixmap(warningIcon)
         self.page.hostname_error_image.setPixmap(warningIcon)
 
-        self.page.show_password.setIcon(QIcon.fromTheme("password-show-off"))
-
         self.clear_errors()
 
         self.page.fullname.textChanged[str].connect(self.on_fullname_changed)
         self.page.username.textChanged[str].connect(self.on_username_changed)
         self.page.hostname.textChanged[str].connect(self.on_hostname_changed)
-        self.page.show_password.toggled.connect(self.on_show_password)
         # self.page.password.textChanged[str].connect(self.on_password_changed)
         # self.page.verified_password.textChanged[str].connect(
         #    self.on_verified_password_changed)
@@ -610,16 +599,6 @@ class PageKde(PageBase):
         self.page.password_debug_warning_label.setVisible(
             'UBIQUITY_DEBUG' in os.environ)
 
-    def on_show_password(self, state):
-        from PyQt5 import QtWidgets
-        from PyQt5.QtGui import QIcon
-
-        modes = (QtWidgets.QLineEdit.Password, QtWidgets.QLineEdit.Normal)
-        icons = ("password-show-off", "password-show-on")
-        self.page.password.setEchoMode(modes[state])
-        self.page.verified_password.setEchoMode(modes[state])
-        self.page.show_password.setIcon(QIcon.fromTheme(icons[state]))
-
     def on_fullname_changed(self):
         # If the user did not manually enter a username create one for him.
         if not self.username_edited:
